#! /usr/bin/env python

import argparse
import pickle
import os


def main():
    parser = argparse.ArgumentParser(description='Start an analysis plugin')
    parser.add_argument('Name', type=str, help='Name of analysis class')
    parser.add_argument('Code', type=str, help='Code of the analysis')
    parser.add_argument('Selection', type=str, help='Serialized selection')
    parser.add_argument('-c', '--config', dest='config', type=str,
                        help='Pickled configuration of analysis')
    parser.add_argument('-cf', '--codefile', dest='codefile',
                        action='store_const', const=True, default=False,
                        help='Code represents a filename containing code '
                             '(default: Code is a string containing code')
    parser.add_argument('-sf', '--selectionfile', dest='selectionfile',
                        action='store_const', const=True, default=False,
                        help='Selection represents a filename containing the '
                             'serialized selection (default: Selection is a '
                             'string')
    parser.add_argument('-dd', '--datadir', type=str, help='The data directory')
    parser.add_argument('-p', '--path', type=str, help='The data directory',
                        default='')

    args = parser.parse_args()

    out = {}

    out['name'] = args.Name
    out['selection'] = args.Selection
    out['config'] = args.config

    if args.codefile:
        f = open(args.Code, 'r')
        out['file'] = f.read()
    else:
        out['file'] = args.Code

    if args.selectionfile:
        f = open(args.Selection, 'r')
        out['selection'] = f.read()
    else:
        out['selection'] = args.Selection

    # Use the supplied path. The data dir parameter is ignored.
    f = open(os.path.join(args.path, 'plugin_data'), 'w')
    pickle.dump(out, f)

if __name__ == '__main__':
    main()